'''
Created Date: Friday, July 21st 2023, 8:14:59 pm
Author: yacper

'''
__version__ = "0.0.5"
__author__="yacper"
__authoremail__="yacper@gmail.com"

import sys


# import warnings

# if sys.version_info < (3, 8):
#     warnings.warn(
#         "为了支持更多特性，请尽快升级 Python 版本到 3.8 及以上"
#     )
#     sys.exit(1)

del sys


from marketwatchdata.MarketWatch import ohlc
